import { Database } from '../database';
import { SeederCollection, LogFn } from '../common';
import { BulkWriteOptions } from 'mongodb';
/**
 * Allows to import collections into database.
 */
export declare class CollectionImporter {
    /**
     * Wrapper for MongoDB database
     */
    db: Database;
    /**
     * Logger instance
     */
    log: LogFn;
    /**
     * Optional MongoDB collection create options
     */
    bulkWriteOptions?: BulkWriteOptions;
    /**
     * Constructs new `CollectionImporter` instance.
     *
     * @param db Database object
     * @param bulkWriteOptions Optional MongoDB bulk write options
     * @param log Optional logger instance
     */
    constructor(db: Database, bulkWriteOptions?: BulkWriteOptions, log?: LogFn);
    /**
     * Imports multiple collections into database.
     *
     * @param collections Array of collections
     */
    import(collections: SeederCollection[]): Promise<void>;
    /**
     * Imports single collection into database.
     *
     * @param collection Collection definition
     */
    private importCollection;
}
